==> qore-xml-module-1.7.1.tar.bz2: qore-xml-module-1.7.1/docs/qlib/SoapDataProviderFactory.qc.dox.h <==
// -*- mode: c++; indent-tabs-mode: nil -*-
//! Qore SoapDataProviderFactory class definition

/** SoapDataProviderFactory.qc Copyright 2019 - 2020 Qore Technologies, s.r.o.

    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
    to deal in the Software without restriction, including without limitation
    the rights to use, copy, modify, merge, publish, distribute, sublicense,
    and/or sell copies of the Software, and to permit persons to whom the
    Software is furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
    DEALINGS IN THE SOFTWARE.
*/

// minimum required Qore version
// assume local scope for variables, do not use "$" signs
// require type definitions everywhere
// strict argument handling
// enable all warnings

//! Contains all public definitions in the SoapDataProvider module
namespace SoapDataProvider {
//! The SOAP data provider factory
class SoapDataProviderFactory : public AbstractDataProviderFactory {

public:
protected:
        static Class cls = new Class("SoapDataProvider");

public:

    //! Returns the name of the data provider factory
    string getName();


    //! Returns static provider information
/** @note the \c name and \c children attributes are not returned as they are dynamic attributes
    */
    hash<DataProviderInfo> getInfo();


    //! Returns the class for the data provider object
    Class getClass();

};
};

==> qore-xml-module-1.8.1.tar.bz2: qore-xml-module-1.8.1/docs/qlib/SoapDataProviderFactory.qc.dox.h <==
// -*- mode: c++; indent-tabs-mode: nil -*-
//! Qore SoapDataProviderFactory class definition

/** SoapDataProviderFactory.qc Copyright 2019 - 2022 Qore Technologies, s.r.o.

    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
    to deal in the Software without restriction, including without limitation
    the rights to use, copy, modify, merge, publish, distribute, sublicense,
    and/or sell copies of the Software, and to permit persons to whom the
    Software is furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
    DEALINGS IN THE SOFTWARE.
*/

//! Contains all public definitions in the SoapDataProvider module
namespace SoapDataProvider {
//! The SOAP data provider factory
class SoapDataProviderFactory : public AbstractDataProviderFactory {

public:
protected:
        //! Data provider type info
        static Class cls = new Class("SoapDataProvider");

        //! Factory info
        const FactoryInfo = ...;


public:

    //! Returns static factory information without \a provider_info
/** @return static factory information without \a provider_info which is provided by @ref getProviderInfo()
    */
protected:
     hash<DataProviderFactoryInfo> getInfoImpl();
public:


    //! Returns static provider information
/** @note the \c name and \c children attributes are not returned as they are dynamic attributes
    */
protected:
     hash<DataProviderInfo> getProviderInfoImpl();
public:


    //! Returns the class for the data provider object
protected:
     Class getClassImpl();
public:

};
};
